<?php
namespace Claromentis\Projects;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"] ?: array()) + array();
class HistoryItem
{
    protected $area;
    protected $is_private = false;
    protected $changes;
    protected $assignees = [];
    public function SetArea($_d7ac0d515b6b86d53a808b6a61d4ac22)
    {
        $this->area = $_d7ac0d515b6b86d53a808b6a61d4ac22;
    }
    public function GetArea()
    {
        return $this->area;
    }
    public function SetChanges($_6be7ef0f685c2a96fcae1fc2ccc30198)
    {
        $this->changes = $_6be7ef0f685c2a96fcae1fc2ccc30198;
    }
    public function GetChanges()
    {
        return $this->changes;
    }
    public function SetPrivate()
    {
        $this->is_private = true;
    }
    public function SetNotPrivate()
    {
        $this->is_private = false;
    }
    public function GetIsPrivate()
    {
        return $this->is_private;
    }
    public function SetAssignees(?array $_5ecedeb8c083d4a2a4ebef5526097f58)
    {
        if ($_5ecedeb8c083d4a2a4ebef5526097f58 === null) {
            $_5ecedeb8c083d4a2a4ebef5526097f58 = [];
        }
        $this->assignees = $_5ecedeb8c083d4a2a4ebef5526097f58;
    }
    public function GetAssignees()
    {
        return $this->assignees;
    }
}